==> mall-center-api-0.1.11-20211122.022520-16-sources.jar: cn/com/duiba/mall/center/api/domain/dto/groupbuy/GroupBuyDetailDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.groupbuy;

import java.io.Serializable;
import java.util.Date;

/**
* 拼团详情表
*/
public class GroupBuyDetailDto implements Serializable {

    private static final long serialVersionUID = 6075532406979803499L;
    /**
    * 主键
    */
    private Long id;

    /**
    * appid
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 关团时间
    */
    private Date groupCloseTime;

    /**
    * 团长cid
    */
    private Long grouperConsumerId;

    /**
    * 团状态， 0创建 1拼团中，10团已满，20 失败，规定时间内未成团，21 失败，开发者失效活动
    */
    private Integer status;

    /**
    * 当前拼团人数
    */
    private Integer currentPeopleNum;

    /**
    * 满团人数
    */
    private Integer fullPeopleNum;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setGroupCloseTime(Date groupCloseTime) {
        this.groupCloseTime = groupCloseTime;
    }

    public Date getGroupCloseTime() {
        return groupCloseTime;
    }

    public void setGrouperConsumerId(Long grouperConsumerId) {
        this.grouperConsumerId = grouperConsumerId;
    }

    public Long getGrouperConsumerId() {
        return grouperConsumerId;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getStatus() {
        return status;
    }

    public void setCurrentPeopleNum(Integer currentPeopleNum) {
        this.currentPeopleNum = currentPeopleNum;
    }

    public Integer getCurrentPeopleNum() {
        return currentPeopleNum;
    }

    public void setFullPeopleNum(Integer fullPeopleNum) {
        this.fullPeopleNum = fullPeopleNum;
    }

    public Integer getFullPeopleNum() {
        return fullPeopleNum;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> mall-center-api-0.1.11-20211123.094957-21-sources.jar: cn/com/duiba/mall/center/api/domain/dto/groupbuy/GroupBuyDetailDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.groupbuy;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
* 拼团详情表
*/
public class GroupBuyDetailDto implements Serializable {

    private static final long serialVersionUID = 6075532406979803499L;
    /**
    * 主键
    */
    private Long id;

    /**
    * appid
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 关团时间
    */
    private Date groupCloseTime;

    /**
    * 团长cid
    */
    private Long grouperConsumerId;

    /**
    * 团状态， 0创建 1拼团中，10团已满，20 失败，规定时间内未成团，21 失败，开发者失效活动
    */
    private Integer status;

    /**
    * 当前拼团人数
    */
    private Integer currentPeopleNum;

    /**
    * 满团人数
    */
    private Integer fullPeopleNum;
    /**
     * 团下已支付的订单
     */
    private List<GroupBuyOrderDto> paySuccessOrderList;

    public List<GroupBuyOrderDto> getPaySuccessOrderList() {
        return paySuccessOrderList;
    }

    public void setPaySuccessOrderList(List<GroupBuyOrderDto> paySuccessOrderList) {
        this.paySuccessOrderList = paySuccessOrderList;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setGroupCloseTime(Date groupCloseTime) {
        this.groupCloseTime = groupCloseTime;
    }

    public Date getGroupCloseTime() {
        return groupCloseTime;
    }

    public void setGrouperConsumerId(Long grouperConsumerId) {
        this.grouperConsumerId = grouperConsumerId;
    }

    public Long getGrouperConsumerId() {
        return grouperConsumerId;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getStatus() {
        return status;
    }

    public void setCurrentPeopleNum(Integer currentPeopleNum) {
        this.currentPeopleNum = currentPeopleNum;
    }

    public Integer getCurrentPeopleNum() {
        return currentPeopleNum;
    }

    public void setFullPeopleNum(Integer fullPeopleNum) {
        this.fullPeopleNum = fullPeopleNum;
    }

    public Integer getFullPeopleNum() {
        return fullPeopleNum;
    }



}
